==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/th/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'ยืนยันการลบเนื้อหาเป็นกลุ่ม',
  'bulk_delete_help'	=> 'ตรวจทานเนื้อหาสำหรับการลบจำนวนมากด้านล่าง เมื่อลบแล้วเนื้อหาเหล่านี้สามารถเรียกคืนได้ แต่จะไม่มีการเชื่อมโยงกับผู้ใช้ที่ได้รับมอบหมายอยู่ในขณะนี้อีกต่อไป',
  'bulk_delete_warn'	=> 'คุณกำลังจะลบ: asset_count',
	'bulk_update'		=> 'ปรับปรุงสินทรัพย์แบบหลายรายการ',
	'bulk_update_help'	=> 'ฟอร์มนี้อนุญาตให้คุณปรับปรุงสินทรัพย์แบบหลายรายการในครั้งเดียว เพียงกรอกข้อมูลที่ต้องการเปลี่ยนแปลงลงในช่อง ช่องใดที่ไม่ได้กรอกข้อมูลจะไม่มีการเปลี่ยนแปลงใดๆ ',
	'bulk_update_warn'	=> 'คุณกำลังแก้ไขคุณสมบัติของสินทรัพย์ :asset_count',
    'checkedout_to'		=> 'เช็คเอ้าท์ให้กับ',
    'checkout_date'		=> 'วันที่เช็คเอ้าท์',
    'checkin_date'		=> 'วันที่เช็คอิน',
    'checkout_to'		=> 'เช็คเอ้าท์ให้กับ',
    'cost'				=> 'ราคาซื้อ',
    'create'			=> 'สร้างสินทรัพย์',
    'date'				=> 'วันที่ซื้อ',
    'depreciation'	    => 'การเสื่อมราคา',
    'depreciates_on'	=> 'คิดค่าเสื่อมราคา',
    'default_location'	=> 'ตำแหน่งพื้นฐาน',
    'eol_date'			=> 'วันที่ EOL',
    'eol_rate'			=> 'เรท EOL',
    'expected_checkin'  => 'วันที่เช็คอินที่คาดหวังไว้',
    'expires'			=> 'หมดอายุ',
    'fully_depreciated'	=> 'หมดค่าเสื่อมราคาแล้ว',
    'help_checkout'		=> 'หากคุณประสงค์ที่จะกำหนดสินทรัพย์นี้ในทันที เลือก "Ready to Deploy" จากรายการสถานะด้านบน ',
    'mac_address'		=> 'MAC Address',
    'manufacturer'		=> 'ผู้ผลิต',
    'model'				=> 'โมเดล',
    'months'			=> 'เดือน',
    'name'				=> 'ชื่อสินทรัพย์',
    'notes'				=> 'หมายเหตุ',
    'order'				=> 'หมายเลขสั่งซื้อ',
    'qr'				=> 'QR Code',
    'requestable'		=> 'ผู้ใช้งานอาจร้องขอสินทรัพย์นี้',
    'select_statustype'	=> 'เลือกประเภทสถานะ',
    'serial'			=> 'ซีเรียล',
    'status'			=> 'สถานะ',
    'tag'				=> 'รหัสทรัพย์สิน',
    'update'			=> 'ปรับปรุงสินทรัพย์',
    'warranty'			=> 'การรับประกัน',
		'warranty_expires'		=> 'การรับประกันหมดอายุ',
    'years'				=> 'ปี',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/th/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'ยืนยันการลบเนื้อหาเป็นกลุ่ม',
  'bulk_delete_help'	=> 'ตรวจทานเนื้อหาสำหรับการลบจำนวนมากด้านล่าง เมื่อลบแล้วเนื้อหาเหล่านี้สามารถเรียกคืนได้ แต่จะไม่มีการเชื่อมโยงกับผู้ใช้ที่ได้รับมอบหมายอยู่ในขณะนี้อีกต่อไป',
  'bulk_delete_warn'	=> 'คุณกำลังจะลบ: asset_count',
    'bulk_update'		=> 'ปรับปรุงสินทรัพย์แบบหลายรายการ',
    'bulk_update_help'	=> 'ฟอร์มนี้อนุญาตให้คุณปรับปรุงสินทรัพย์แบบหลายรายการในครั้งเดียว เพียงกรอกข้อมูลที่ต้องการเปลี่ยนแปลงลงในช่อง ช่องใดที่ไม่ได้กรอกข้อมูลจะไม่มีการเปลี่ยนแปลงใดๆ ',
    'bulk_update_warn'	=> 'คุณกำลังแก้ไขคุณสมบัติของสินทรัพย์ :asset_count',
    'checkedout_to'		=> 'เช็คเอ้าท์ให้กับ',
    'checkout_date'		=> 'วันที่เช็คเอ้าท์',
    'checkin_date'		=> 'วันที่เช็คอิน',
    'checkout_to'		=> 'เช็คเอ้าท์ให้กับ',
    'cost'				=> 'ราคาซื้อ',
    'create'			=> 'สร้างสินทรัพย์',
    'date'				=> 'วันที่ซื้อ',
    'depreciation'	    => 'การเสื่อมราคา',
    'depreciates_on'	=> 'คิดค่าเสื่อมราคา',
    'default_location'	=> 'ตำแหน่งพื้นฐาน',
    'eol_date'			=> 'วันที่ EOL',
    'eol_rate'			=> 'เรท EOL',
    'expected_checkin'  => 'วันที่เช็คอินที่คาดหวังไว้',
    'expires'			=> 'หมดอายุ',
    'fully_depreciated'	=> 'หมดค่าเสื่อมราคาแล้ว',
    'help_checkout'		=> 'หากคุณประสงค์ที่จะกำหนดสินทรัพย์นี้ในทันที เลือก "Ready to Deploy" จากรายการสถานะด้านบน ',
    'mac_address'		=> 'MAC Address',
    'manufacturer'		=> 'ผู้ผลิต',
    'model'				=> 'โมเดล',
    'months'			=> 'เดือน',
    'name'				=> 'ชื่อสินทรัพย์',
    'notes'				=> 'หมายเหตุ',
    'order'				=> 'หมายเลขสั่งซื้อ',
    'qr'				=> 'QR Code',
    'requestable'		=> 'ผู้ใช้งานอาจร้องขอสินทรัพย์นี้',
    'select_statustype'	=> 'เลือกประเภทสถานะ',
    'serial'			=> 'ซีเรียล',
    'status'			=> 'สถานะ',
    'tag'				=> 'รหัสทรัพย์สิน',
    'update'			=> 'ปรับปรุงสินทรัพย์',
    'warranty'			=> 'การรับประกัน',
        'warranty_expires'		=> 'การรับประกันหมดอายุ',
    'years'				=> 'ปี',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
